import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

import supplierRoutes from './modules/supplier'
import authRoutes from './modules/auth'
import productRoutes from './modules/product'
import reviewRoutes from './modules/review'
import heloperRoutes from './modules/helper'
// import proxyRoutes from './modules/proxy'
import docRoutes from './modules/doc'
import feedbackRoutes from './modules/feedback'
import clubRoutes from './modules/authUser'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
    proxy: false
  }
 */

// 默认路由列表 全部用户都可以访问
export const constantRoutes = [
  // 登录
  // 首页显示的页面
  {
    path: '/',
    component: Layout,
    redirect: '/login'
  },
  {
    path: '/login',
    component: () => import(/* webpackChunkName: "static/js/login" */ '@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/proxy',
    component: () => import('@/views/authentic/proxy/proxy'),
    hidden: true
  },
  // 修改密码
  {
    component: Layout,
    path: '/password',
    name: 'Password',
    redirect: 'edit',
    hidden: true,
    meta: { title: '密码管理', id: 40 },
    children: [
      {
        path: 'edit',
        component: () => import('@/views/password/index'),
        name: 'Edit',
        meta: { title: '修改密码', id: 2 }
      }
    ]
  }
]

// 需要权限访问的路由列表
export const asyncRoutes = [
  ...supplierRoutes,
  ...authRoutes,
  ...productRoutes,
  ...reviewRoutes,
  ...clubRoutes,
  // ...proxyRoutes,
  ...docRoutes,
  ...feedbackRoutes,
  ...heloperRoutes,

  // 404页面 放在最后面
  { path: '*', redirect: '/404', hidden: true }
]

// 创建路由对象
const createRouter = () =>
  new Router({
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
  })

const router = createRouter()

// 重置路由
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
